summaryrefslogtreecommitdiffstats
path: root/components/favicon_base/favicon_callback.h
diff options
context:
space:
mode:
Diffstat (limited to 'components/favicon_base/favicon_callback.h')
-rw-r--r--components/favicon_base/favicon_callback.h11
1 files changed, 6 insertions, 5 deletions
diff --git a/components/favicon_base/favicon_callback.h b/components/favicon_base/favicon_callback.h
index 437c4ec..7616a11 100644
--- a/components/favicon_base/favicon_callback.h
+++ b/components/favicon_base/favicon_callback.h
@@ -11,7 +11,7 @@
namespace favicon_base {
-struct FaviconBitmapResult;
+struct FaviconRawBitmapResult;
struct FaviconImageResult;
// Callback for functions that can be used to return a |gfx::Image| and the
@@ -19,13 +19,14 @@ struct FaviconImageResult;
typedef base::Callback<void(const FaviconImageResult&)> FaviconImageCallback;
// Callback for functions returning raw data for a favicon. In
-// |FaviconBitmapResult|, the data is not yet converted as a |gfx::Image|.
-typedef base::Callback<void(const FaviconBitmapResult&)> FaviconRawCallback;
+// |FaviconRawBitmapResult|, the data is not yet converted as a |gfx::Image|.
+typedef base::Callback<void(const FaviconRawBitmapResult&)>
+ FaviconRawBitmapCallback;
// Callback for functions returning raw data for a favicon in multiple
// resolution. In |FaviconBitmapResult|, the data is not yet converted as a
// |gfx::Image|.
-typedef base::Callback<void(const std::vector<FaviconBitmapResult>&)>
+typedef base::Callback<void(const std::vector<FaviconRawBitmapResult>&)>
FaviconResultsCallback;
} // namespace favicon_base
@@ -19,13 +19,14 @@ struct FaviconImageResult;
// Callback for functions returning raw data for a favicon in multiple
-// resolution. In |FaviconBitmapResult|, the data is not yet converted as a
+// resolution. In |FaviconRawBitmapResult|, the data is not yet converted as a
// |gfx::Image|.